Calculate stature estimation according to Breitinger 1938 & Bach 1965.
Source:R/breitinger_bach_1965.R
breitinger_bach_1965.RdStature estimation (mm) based on the mean of different regression calculations, separated by sex (Breitinger 1938, Bach 1965). Bone measures used: Hum2, Hum1, Rad1b, Fem1, Tib1b.
If bone measures for left and right are provided the mean value will be used, but for statistic information 2 bones will be counted (n_measures). If sex is indet. the mean of male and female stature estimation is given. Breitinger (1938) does not show the regression equation for Hum1, but the equation can be derived from the values given in the table p. 272 (see Siegmund 2010, p. 112). In contrast, Bach (1965) gives both equations. In addition, Bach (1965, 20) states to use only one of the Humeri measures for estimation (Hum1 or Hum2 or the mean of both) to avoid inadmissable multiplication of the bone within the stature estimation.
Returns a data.frame with:
ind: individual identifyer (rownames),
sex: as provided for calculation: m, f, indet.
stature: estimated on the provided sex and bone measures,
bone (measure(s)): bones used for calculation,
if_female (stature): columns with alternative stature for three sex classes,
if_male (stature),
if_indet. (stature) and
n_measures: number of bone measures included: e.g. 2 Fem2 (left, right) + 1 Tib1
References
Bach H (1965).
“Zur Berechnung der Körperhöhe aus den langen Gliedmaßenknochen weiblicher Skelette.”
Anthropologischer Anzeiger, 29, 12–21.
ISSN 0003-5548.
https://www.jstor.org/stable/29537886.
Breitinger E (1937).
“Zur Berechnung der Körperhöhe aus den langen Gliedmaßenknochen.”
Anthropologischer Anzeiger, 14(3/4), 249–274.
ISSN 0003-5548.
https://www.jstor.org/stable/29536541.
Siegmund F (2010).
Die Körpergröße der Menschen in der Ur- und Frühgeschichte Mitteleuropas und ein Vergleich ihrer anthropologischen Schätzmethoden.
Books on Demand, Norderstedt.
ISBN 978-3-8391-5314-7.
Author
Christoph Rinne crinne@ufg.uni-kiel.de
Examples
# Read example dataset into a data frame
x <- statuAAR::Bach1965
# Prepare tabled data into a long list (statuaar_data_table)
dl.bach1965 <- statuAAR::prep.statuaar.data(x, d.form = "wide",
measures.names = "short", sex = "sex", stats = FALSE)
#> Warning: No individual identifier provided, each record (row) will be counted as one individual.
# Calculate stature estimation using a given formula.
bb65.estimates <- statuAAR::getStature(c("bb65"), dl.bach1965)
# Extract the corresponding data frame from the returned list object.
bb65.estimates[["bb65"]] |> head(6)
#> sex stature bone if_female if_male if_indet n_measures
#> 32 m 1540 Hum2, Rad1b, Fem1, Tib1b 1531 1540 1536 4
#> 33 m 1550 Hum2, Rad1b, Fem1, Tib1b 1538 1550 1544 4
#> 34 m 1560 Hum2, Rad1b, Fem1, Tib1b 1546 1560 1553 4
#> 35 m 1570 Hum2, Rad1b, Fem1, Tib1b 1554 1570 1562 4
#> 36 m 1580 Hum2, Rad1b, Fem1, Tib1b 1561 1580 1571 4
#> 37 m 1590 Hum2, Rad1b, Fem1, Tib1b 1570 1590 1580 4