Retreaves the long names of the formula abbreviations out of the list with names and bone measures for each formula.
Author
Christoph Rinne crinne@ufg.uni-kiel.de
Examples
# Get the long names of the function abbreviations
getFormulaNames(c('bb65', 'tg01'))
#> [1] "breitinger_bach_1965" "trotter_gleser_1952_an"