Skip to contents

Stature estimation (mm) based on the hierarchy of different regression calculations, separated by sex and region (Ruff et al 2012). The authors provide various formulas, whereby they primarily use the sum of femur and tibia length for the regional groups due to its greater accuracy, while the undifferentiated calculations are based on separate measurements of the femur, humerus and radius. Depending on the measurements provided for each individual, regional assignment may result in a missing stature estimate. In addition, as an alternative to each separately calculated regional group, a calculation can be performed for a mixed data set. The authors do not refer to a hierarchical application of the respective formulas, but the repeated emphasis on %SEE as a quality characteristic suggests this. In addition, averaging the results of both formulas for the respective regional group would inadmissibly include the length of the tibia multiple times.

Bone measures (Fem1, Tib1, Hum1, Rad1) used in hierarchical order of percent standard error of estimate (%SEE).

If bone measures for left and right are provided the mean value will be used #' (s. Auerbach/Ruff 2010), but for statistic information 2 bones will be counted (n_measures).

Returns a data.frame with:

  • ind: individual identifyer (rownames),

  • sex: as provided for calculation: m, f, indet.

  • stature: estimated on the provided sex and bone measures,

  • bone (measure(s)): bones used for calculation,

  • if_female (stature): columns with alternative stature for three sex classes,

  • if_male (stature),

  • if_indet. (stature) and

  • n_measures: number of bone measures included: e.g. 2 Fem2 (left, right) + 1 Tib1

Usage

ruff_etal_2012_a(df)

Arguments

df

data.frame of type statuaar_data_table, containing informations on individual, bone and measurement.

Value

data.frame with calculated stature and related information per individual.

References

Auerbach BM, Ruff CB (2010). “Stature estimation formulae for indigenous North American populations.” American Journal of Physical Anthropology, 141(2), 190–207. ISSN 1096-8644. doi:10.1002/ajpa.21131 . https://onlinelibrary.wiley.com/doi/abs/10.1002/ajpa.21131.

Ruff CB, Holt BM, Niskanen M, Sladék V, Berner M, Garofalo E, Garvin HM, Hora M, Maijanen H, Niinimäki S, Salo K, Schuplerová E, Tompkins D (2012). “Stature and body mass estimation from skeletal remains in the European Holocene.” American Journal of Physical Anthropology, 148(4), 601–617. ISSN 1096-8644. doi:10.1002/ajpa.22087 . https://onlinelibrary.wiley.com/doi/abs/10.1002/ajpa.22087.

Ruff C (2018). Skeletal variation and adaptation in Europeans: upper Paleolithic to the Twentieth Century. John Wiley & Sons, Hoboken, NJ. ISBN 978-1-118-62796-9 978-1-118-62803-4.

Author

Christoph Rinne crinne@ufg.uni-kiel.de

Examples

# Read example dataset into a data frame.
# Ruff et al 2012 cite Trotter & Gleser (White).
x <- statuAAR::TrotterGleser1952
x <- x[x$Race == "White", ]

# Create & check the data frame of mesures concordance for Trotter & Gleser 1952
measures.concordance <- create.measures.concordance()
measures.concordance[measures.concordance$own != "",]
#>    short      long  own
#> 1   Fem1   Femur.1  Fem
#> 10  Hum1 Humerus.1  Hum
#> 19  Rad1  Radius.1  Rad
#> 28  Tib1   Tibia.1  Tib
#> 37  Uln1    Ulna.1 Ulna

# Prepare statuaar_data_table
dl.tgb <- statuAAR::prep.statuaar.data(x, d.form = "wide", ind = "Appendix_row",
                           sex = "Sex", measures.names = "own", stats = FALSE)

# Calculate stature estimation using a given formula.
# Retrieve the first element of the list and display the first 6 lines.
statuAAR::getStature(c("r12a"), dl.tgb)[[1]] |> head(6)
#>      sex stature bone if_female if_male if_indet n_measures
#> 1_1    m    1465 Fem1      1460    1465     1460          1
#> 1_10   m    1568 Fem1      1563    1568     1566          1
#> 1_11   m    1579 Fem1      1573    1579     1577          1
#> 1_12   m    1590 Fem1      1584    1590     1588          1
#> 1_13   m    1601 Fem1      1595    1601     1599          1
#> 1_14   m    1612 Fem1      1606    1612     1610          1
# ruff_etal_2012_a(dl.tgb) # The alternative.