Calculate stature estimation according to: Ruff el al 2012, South.
Source:R/ruff_etal_2012_s.R
ruff_etal_2012_s.RdStature estimation (mm) based on the hierarchy of different regression calculations, separated by sex and region (Ruff et al 2012). The authors provide various formulas, whereby they primarily use the sum of femur and tibia length for the regional groups due to its greater accuracy, while the undifferentiated calculations are based on separate measurements of the femur, humerus and radius. Depending on the measurements provided for each individual, regional assignment may result in a missing stature estimate. In addition, as an alternative to each separately calculated regional group, a calculation can be performed for a mixed data set. The authors do not refer to a hierarchical application of the respective formulas, but the repeated emphasis on %SEE as a quality characteristic suggests this. In addition, averaging the results of both formulas for the respective regional group would inadmissibly include the length of the tibia multiple times.
Bone measures (Fem1+Tib1, Tib1) used in hierarchical order of percent standard error of estimate (%SEE). The addition of individual bone measurements is performed during the calculation.
If bone measures for left and right are provided the mean value will be used, but for statistic information 2 bones will be counted (n_measures).
Returns a data.frame with:
ind: individual identifyer (rownames),
sex: as provided for calculation: m, f, indet.
stature: estimated on the provided sex and bone measures,
bone (measure(s)): bones used for calculation,
if_female (stature): columns with alternative stature for three sex classes,
if_male (stature),
if_indet. (stature) and
n_measures: number of bone measures included: e.g. 2 Fem2 (left, right) + 1 Tib1
References
Auerbach BM, Ruff CB (2010).
“Stature estimation formulae for indigenous North American populations.”
American Journal of Physical Anthropology, 141(2), 190–207.
ISSN 1096-8644.
doi:10.1002/ajpa.21131
.
https://onlinelibrary.wiley.com/doi/abs/10.1002/ajpa.21131.
Ruff CB, Holt BM, Niskanen M, Sladék V, Berner M, Garofalo E, Garvin HM, Hora M, Maijanen H, Niinimäki S, Salo K, Schuplerová E, Tompkins D (2012).
“Stature and body mass estimation from skeletal remains in the European Holocene.”
American Journal of Physical Anthropology, 148(4), 601–617.
ISSN 1096-8644.
doi:10.1002/ajpa.22087
.
https://onlinelibrary.wiley.com/doi/abs/10.1002/ajpa.22087.
Ruff C (2018).
Skeletal variation and adaptation in Europeans: upper Paleolithic to the Twentieth Century.
John Wiley & Sons, Hoboken, NJ.
ISBN 978-1-118-62796-9 978-1-118-62803-4.
Author
Christoph Rinne crinne@ufg.uni-kiel.de
Examples
# Read example dataset into a data frame.
# Ruff et al 2012 cite Trotter & Gleser (White).
x <- statuAAR::TrotterGleser1952
x <- x[x$Race == "White", ]
# Create & check the data frame of mesures concordance for Trotter & Gleser 1952
measures.concordance <- create.measures.concordance()
measures.concordance[measures.concordance$own != "",]
#> short long own
#> 1 Fem1 Femur.1 Fem
#> 10 Hum1 Humerus.1 Hum
#> 19 Rad1 Radius.1 Rad
#> 28 Tib1 Tibia.1 Tib
#> 37 Uln1 Ulna.1 Ulna
# Prepare statuaar_data_table
dl.tgb <- statuAAR::prep.statuaar.data(x, d.form = "wide", ind = "Appendix_row",
sex = "Sex", measures.names = "own", stats = FALSE)
# Calculate stature estimation using a given formula.
# Retrieve the first element of the list and display the first 6 lines.
statuAAR::getStature(c("r12s"), dl.tgb)[[1]] |> head(6)
#> sex stature bone if_female if_male if_indet n_measures
#> 1_1 m 1438 Fem1+Tib1 1417 1438 1425 2
#> 1_10 m 1541 Fem1+Tib1 1526 1541 1534 2
#> 1_11 m 1552 Fem1+Tib1 1538 1552 1546 2
#> 1_12 m 1564 Fem1+Tib1 1550 1564 1558 2
#> 1_13 m 1575 Fem1+Tib1 1562 1575 1570 2
#> 1_14 m 1586 Fem1+Tib1 1573 1586 1581 2
# ruff_etal_2012_s(dl.tgb) # The alternative.