Stature estimation (mm) based on the mean of different regression calculations, separated by sex. Bone measures used: Hum1, Rad2, Uln2, Fem1, Tib1, Fib1
If bone measures for left and right are provided the mean value will be used, but for statistic information 2 bones will be counted (n_measures). If sex is indet. the mean of male and female stature estimation is given. To retrieve the estimated stature 20 mm will be substracted from the resulting mean value.
Returns a data.frame with:
ind: individual identifyer (rownames),
sex: as provided for calculation: m, f, indet.
stature: estimated on the provided sex and bone measures,
bone (measure(s)): bones used for calculation,
if_female (stature): columns with alternative stature for three sex classes,
if_male (stature),
if_indet. (stature) and
n_measures: number of bone measures included: e.g. 2 Fem2 (left, right) + 1 Tib1
References
Telkkã A (1950).
“On the prediction of human stature from the long bones.”
Acta Anatomica, 9, 103–117.
Author
Christoph Rinne crinne@ufg.uni-kiel.de
Examples
# Read example dataset into a data frame.
x <- statuAAR::TrotterGleser1952
# Create & check the data frame of mesures concordance for Trotter & Gleser 1952
measures.concordance <- create.measures.concordance()
measures.concordance[measures.concordance$own != "",]
#> short long own
#> 1 Fem1 Femur.1 Fem
#> 10 Hum1 Humerus.1 Hum
#> 19 Rad1 Radius.1 Rad
#> 28 Tib1 Tibia.1 Tib
#> 37 Uln1 Ulna.1 Ulna
# Prepare statuaar_data_table
dl.tgb <- statuAAR::prep.statuaar.data(x, d.form = "wide", ind = "Appendix_row",
sex = "Sex", measures.names = "own", stats = FALSE)
# Calculate stature estimation using a given formula.
# Retrieve the first element of the list and display the first 6 lines.
statuAAR::getStature(c("te50"), dl.tgb)[[1]] |> head(6)
#> sex stature bone if_female if_male if_indet n_measures
#> 1_1 m 1513 Hum1, Fem1, Tib1 1463 1513 1488 3
#> 1_10 m 1589 Hum1, Fem1, Tib1 1532 1589 1560 3
#> 1_11 m 1600 Hum1, Fem1, Tib1 1542 1600 1571 3
#> 1_12 m 1609 Hum1, Fem1, Tib1 1551 1609 1580 3
#> 1_13 m 1618 Hum1, Fem1, Tib1 1558 1618 1588 3
#> 1_14 m 1626 Hum1, Fem1, Tib1 1566 1626 1596 3
# telkkae_1950(dl.tgb) # The alternative.